
# THIRD-PARTY LICENSES

This project includes third-party libraries and components, licensed under their respective open source licenses.
Hancom, Inc. distributes the veraPDF components under the Mozilla Public License 2.0 (MPL-2.0), chosen from dual-licensed options.

| Component                         | Version                 | License                                      | Download URL                                                                                          |
|-----------------------------------|-------------------------|----------------------------------------------|-------------------------------------------------------------------------------------------------------|
| API Guardian                      | 1.1.0                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apiguardian/apiguardian-api/1.1.0/                                 |
| Apache Commons Logging            | 1.3.4                   | Apache-2.0                                   | https://repo1.maven.org/maven2/commons-logging/commons-logging/1.3.4/                                 |
| Apache PDFBox                     | 3.0.4                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/pdfbox/pdfbox/3.0.4/                                        |
| Apache PDFBox FontBox             | 3.0.4                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/pdfbox/fontbox/3.0.4/                                       |
| Apache PDFBox IO                  | 3.0.4                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/pdfbox/pdfbox-io/3.0.4/                                     |
| Apache PDFBox JBIG2 ImageIO plugin| 3.0.3                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/pdfbox/jbig2-imageio/3.0.3/                                 |
| ASM                               | 9.5                     | BSD-3-Clause                                 | https://repo1.maven.org/maven2/org/ow2/asm/asm/9.5/                                                   |
| ASM Commons                       | 9.5                     | BSD-3-Clause                                 | https://repo1.maven.org/maven2/org/ow2/asm/asm-commons/9.5/                                           |
| ASM Tree                          | 9.5                     | BSD-3-Clause                                 | https://repo1.maven.org/maven2/org/ow2/asm/asm-tree/9.5/                                              |
| Classworlds                       | 1.1-alpha-2             | Plexus Classworlds License                   | https://repo1.maven.org/maven2/classworlds/classworlds/1.1-alpha-2/                                   |
| Commons CLI                       | 1.4                     | Apache-2.0                                   | https://repo1.maven.org/maven2/commons-cli/commons-cli/1.4/                                           |
| Default Plexus Container          | 1.0-alpha-9             | Apache-2.0                                   | https://repo1.maven.org/maven2/org/codehaus/plexus/plexus-container-default/1.0-alpha-9/              |
| Doxia Sitetools                   | 1.0                     | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/doxia/doxia-sink-api/1.0/                             |
| Jackson Annotations               | 2.15.0                  | Apache-2.0                                   | https://repo1.maven.org/maven2/com/fasterxml/jackson/core/jackson-annotations/2.15.0/                 |
| Jackson Core                      | 2.15.0                  | Apache-2.0                                   | https://repo1.maven.org/maven2/com/fasterxml/jackson/core/jackson-core/2.15.0/                        |
| Jackson Databind                  | 2.15.0                  | Apache-2.0                                   | https://repo1.maven.org/maven2/com/fasterxml/jackson/core/jackson-databind/2.15.0/                    |
| JaCoCo                            | 0.8.10                  | EPL-2.0                                      | https://repo1.maven.org/maven2/org/jacoco/jacoco/0.8.10/                                              |
| Jakarta Activation API            | 1.2.0                   | CDDL-1.1 (chosen from dual-licensed options) | https://repo1.maven.org/maven2/javax/activation/javax.activation-api/1.2.0/                           |
| JAI ImageIO Core                  | 1.4.0                   | BSD-3-Clause                                 | https://repo1.maven.org/maven2/com/github/jai-imageio/jai-imageio-core/1.4.0/                         |
| JAI ImageIO JPEG2000              | 1.3.0                   | JJ2000 License                               | https://repo1.maven.org/maven2/com/github/jai-imageio/jai-imageio-jpeg2000/1.3.0/                    |
| JAXB API                          | 2.4.0-b180830.0359      | CDDL-1.1                                     | https://repo1.maven.org/maven2/javax/xml/bind/jaxb-api/2.4.0-b180830.0359/                            |
| JAXB Core                         | 2.3.0.1                 | CDDL-1.1                                     | https://repo1.maven.org/maven2/com/sun/xml/bind/jaxb-core/2.3.0.1/                                    |
| JAXB Implementation               | 2.3.2                   | EDL-1.0                                      | https://repo1.maven.org/maven2/com/sun/xml/bind/jaxb-impl/2.3.2/                                      |
| JUnit Jupiter (Aggregator)        | 5.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/jupiter/junit-jupiter/5.6.2/                                 |
| JUnit Jupiter API                 | 5.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/jupiter/junit-jupiter-api/5.6.2/                             |
| JUnit Jupiter Engine              | 5.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/jupiter/junit-jupiter-engine/5.6.2/                          |
| JUnit Jupiter Params              | 5.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/jupiter/junit-jupiter-params/5.6.2/                          |
| JUnit Platform Commons            | 1.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/platform/junit-platform-commons/1.6.2/                       |
| JUnit Platform Engine             | 1.6.2                   | EPL-2.0                                      | https://repo1.maven.org/maven2/org/junit/platform/junit-platform-engine/1.6.2/                        |
| OpenTest4J                        | 1.2.0                   | MIT                                          | https://repo1.maven.org/maven2/org/opentest4j/opentest4j/1.2.0/                                       |
| Maven Artifact                    | 2.0.2                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/maven-artifact/2.0.2/                                 |
| Maven Artifact Manager            | 2.0.2                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/maven-artifact-manager/2.0.2/                         |
| Maven Plugin API                  | 2.0.6                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/maven-plugin-api/2.0.6/                               |
| Maven Reporting API               | 3.0                     | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/maven-reporting-api/3.0/                              |
| Maven Repository Metadata Model   | 2.0.2                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/maven-repository-metadata/2.0.2/                      |
| Maven Shared File Management API  | 1.2.1                   | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/shared/maven-shared-file-management/1.2.1/            |
| Maven Shared I/O API              | 1.1                     | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/shared/maven-shared-io/1.1/                           |
| Maven Wagon API                   | 1.0-alpha-6             | Apache-2.0                                   | https://repo1.maven.org/maven2/org/apache/maven/wagon/wagon-provider-api/1.0-alpha-6/                 |
| Mozilla Rhino                     | 1.7.13                  | MPL-2.0                                      | https://repo1.maven.org/maven2/org/mozilla/rhino/1.7.13/                                              |
| Plexus Utils                      | 3.0.24                  | Apache-2.0                                   | https://repo1.maven.org/maven2/org/codehaus/plexus/plexus-utils/3.0.24/                               |
| StAX Utils                        | 20070216                | BSD-3-Clause                                 | https://repo1.maven.org/maven2/net/java/dev/stax-utils/stax-utils/20070216/                           |
| veraPDF Core                      | 1.29.21                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/core/1.29.21/                                              |
| veraPDF Metadata Fixer            | 1.29.76                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/metadata-fixer/1.29.76/                                    |
| veraPDF Parser                    | 1.29.36                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/parser/1.29.36/                                            |
| veraPDF PDF Model                 | 1.29.3                  | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/pdf-model/1.29.3/                                          |
| veraPDF Validation Model          | 1.29.76                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/validation-model/1.29.76/                                  |
| veraPDF XMP Core                  | 1.29.21                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/verapdf-xmp-core/1.29.21/                                  |
| veraPDF WCAG Algorithms           | 1.29.11                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/wcag-algorithms/1.29.11/                                   |
| veraPDF WCAG Validation           | 1.29.76                 | MPL-2.0                                      | https://repo1.maven.org/maven2/org/verapdf/wcag-validation/1.29.76/                                   |
